#
# spec file for package tlp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name TLP
%define systemd_sleepdir %{_unitdir}/system-sleep
%if 0%{?suse_version} > 01500
%define _udevdir %(pkg-config --variable udev_dir udev || echo %{_prefix}/lib/udev)
%else
%{!?_udevdir: %define _udevdir %{_prefix}/lib/udev}
%endif
%{!?_udevrulesdir: %define _udevrulesdir %{_udevdir}/rules.d}

Name:           tlp
Version:        1.5.0
Release:        bp155.1.8
Summary:        Tools to save battery power on laptops
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Group:          Hardware/Mobile
URL:            http://linrunner.de/tlp
Source:         https://github.com/linrunner/%{_name}/archive/%{version}.tar.gz#/%{_name}-%{version}.tar.gz
Source10:       tlp-rpmlintrc
BuildRequires:  gzip
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(udev)
Requires:       hdparm
Requires:       iw
Requires:       pciutils
Requires:       rfkill
Requires:       usbutils
Requires:       util-linux >= 2.17
Requires(pre):  systemd
Recommends:     %{name}-rdw = %{version}
Recommends:     ethtool
Recommends:     lsb-release
Recommends:     smartmontools
Conflicts:      laptop-mode-tools
Conflicts:      power-profiles-daemon
BuildArch:      noarch
%{?systemd_ordering}

%description
TLP implements advanced power management for Linux.
TLP is a pure command line tool with automated background tasks.
It does not contain a GUI.

%package rdw
Summary:        TLP Radio Device Wizard
Group:          Hardware/Mobile
Requires:       NetworkManager >= 1.20
Requires:       tlp = %{version}
Requires(pre):  systemd
BuildArch:      noarch

%description rdw
TLP implements advanced power management for Linux.
TLP is a pure command line tool with automated background tasks.
It does not contain a GUI.

Switch radios upon network connect/disconnect and dock/undock.

%prep
%setup -q -n %{_name}-%{version}

%build
make %{?_smp_mflags} V=1 \
  TLP_ULIB=%{_udevdir} \
  TLP_SYSD=%{_unitdir}

%install
%make_install \
  TLP_WITH_SYSTEMD=1           \
  TLP_WITH_ELOGIND=0           \
  TLP_NO_INIT=1                \
  TLP_ULIB=%{_udevdir} \
  TLP_SYSD=%{_unitdir} \
  TLP_SDSL=%{systemd_sleepdir}

make install-man      DESTDIR=%{buildroot}
make install-man-rdw  DESTDIR=%{buildroot}

ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rctlp
mkdir -p %{buildroot}%{_prefix}/lib/NetworkManager/dispatcher.d
mv %{buildroot}%{_sysconfdir}/NetworkManager/dispatcher.d/99tlp-rdw-nm %{buildroot}%{_prefix}/lib/NetworkManager/dispatcher.d/99tlp-rdw-nm

%pre
%service_add_pre tlp.service

%post
%service_add_post tlp.service
/usr/bin/systemctl mask systemd-rfkill.service
/usr/bin/systemctl mask systemd-rfkill.socket
/usr/bin/systemctl mask power-profiles-daemon.service

%postun
%service_del_postun tlp.service
if [ $1 -eq 0 ] ; then
    /usr/bin/systemctl unmask systemd-rfkill.service
    /usr/bin/systemctl unmask systemd-rfkill.socket
    /usr/bin/systemctl unmask power-profiles-daemon.service
fi

%preun
%service_del_preun tlp.service

%post rdw
/usr/bin/systemctl enable NetworkManager-dispatcher.service >/dev/null 2>&1 || :

%files
%license COPYING LICENSE
%doc AUTHORS changelog README.rst
%dir %{_sysconfdir}/%{name}.d
%dir %{systemd_sleepdir}
%dir %{_datadir}/metainfo/
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%config(noreplace) %{_sysconfdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}.d/00-template.conf
%{_sysconfdir}/%{name}.d/README
%{systemd_sleepdir}/tlp
%{_bindir}/bluetooth
%{_bindir}/run-on-{ac,bat}
%{_bindir}/%{name}-stat
%{_bindir}/nfc
%{_bindir}/wifi
%{_bindir}/wwan
%{_sbindir}/%{name}
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service
%{_datadir}/%{name}/
%{_datadir}/metainfo/de.linrunner.tlp.metainfo.xml
%{_udevdir}/%{name}-usb-udev
%{_udevrulesdir}/85-%{name}.rules
%{_localstatedir}/lib/%{name}/
%{_datadir}/bash-completion/completions/*
%exclude %{_datadir}/bash-completion/completions/tlp-rdw
%{_mandir}/man?/*.?%{?ext_man}
%exclude %{_mandir}/man8/%{name}-rdw.8%{?ext_man}

%files rdw
%dir %{_prefix}/lib/NetworkManager
%dir %{_prefix}/lib/NetworkManager/dispatcher.d
%attr(0755,root,root) %{_prefix}/lib/NetworkManager/dispatcher.d/99tlp-rdw-nm
%{_bindir}/%{name}-rdw
%{_udevrulesdir}/85-%{name}-rdw.rules
%{_udevdir}/%{name}-rdw-udev
%{_mandir}/man8/%{name}-rdw.8%{?ext_man}
%{_datadir}/bash-completion/completions/%{name}-rdw

%changelog
* Mon May 23 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Fix SourceURL (misplaced space) for Factory submission
* Wed May 18 2022 Stefan Schubert <schubi@suse.de>
- Moved 99tlp-rdw-nm from user specif directory
  /etc/NetworkManager/dispatcher.d to vendor specific directory
  /usr/lib/NetworkManager/dispatcher.d. So, users changes can
  still be done in /etc and will not be overwritten by an update.
* Mon Apr 18 2022 popov895@ukr.net
- Due to conflicts with rfkill, we need to additionally mask the systemd-rfkill.socket
- Update to 1.5.0 07.01.2022
- * Features
    Battery:
  - Sony laptops: stop threshold 50/80/100%% aka "battery care limiter"
  - ThinkPads:
  - Use new sysfs attribute 'charge_behaviour' for recalibration
  - Support T400 running coreboot via natacpi (Issue #601)
  - tlp-stat -b: display "cycle_count = 0"  with the note "or not supported"
    Radio Devices:
  - Add support for switching NFC devices
  - Remove support for wireless-tools (iwconfig)
- * Bugfixes
    tlp-stat:
  - drop PM_RUNTIME=y kernel config recommendation
    Battery:
  - ASUS laptops: apply stop threshold reliably on boot and after hibernate
    (Issue #589)
    Disks:
  - tlp-stat -d: display correct sysfs path for disk runtime pm:
    /sys/block/<DISK>/device/power/control (Issue #606)
* Tue Dec 28 2021 lars@linux-schulserver.de - 1.4.0
- package bash completions for tlp-rdw in the corresponding
  sub-package (bsc#1180496)
- add tlp-rpmlintrc to mark some rpmlint warnings as known good
- Fix bsc#1181279, bsc#1179635, bsc#1177313 - Failed to preset
  unit: Unit file tlp-sleep.service does not exist.
- As tlp somehow conflicts with rfkill and power-profiles-daemon
  running at the same time, lets mask these services, when tlp is
  installed. ...and obviously unmask them again on uninstall.
- Require at least NetworkManager >= 1.20
- define _udev(,rules)dir, if not already set (for Leap)
- Pre-Require systemd (and BuildRequire systemd-rpm-macros) for
  completeness
- tlp is not activated per default (bsc#1183235), as it may conflict
  with other Laptop mode tools. At the moment, users have to manually
  activate the service via 'sudo systemctl enable --now tlp.service'
* Thu Nov 11 2021 Mikael S <mikaels@iki.fi>
- Update to 1.4.0 24.09.2021
- * Features
    Audio:
  - SOUND_POWER_SAVE_ON_AC: change default to enabled (Issue #495)
    Battery:
  - "Battery Features" renamed to "Battery Care"
  - Introduce plugins to support Battery Care for non-ThinkPads:
  - ASUS laptops: stop threshold
  - Huawei MateBooks: start and stop threshold
  - LG Gram laptops: stop threshold at 80%% aka "battery care limit"
  - Lenovo laptops: stop threshold at 60%% aka "battery conservation mode"
  - Samsung laptops: stop threshold at 80%% aka "battery life extender"
  - ThinkPads
  - Allow deactivation of the start threshold (START_CHARGE_THRESH_BATx=0)
  - Discharge malfunction: hint to check battery and charger
  - Use standard sysfs attributes for charge thresholds
    (Issue #513)
  - Flag ThinkPad L512 as "unsupported"
  - Validate charge threshold configuration, don't fail silently
  - tlp-stat -b
  - Battery Care: show plugin, supported features, driver usage and
    related kernel module(s)
  - Map battery state "Unknown" to "Idle" for clarity
    Configuration:
  - tlp-stat --cdiff: show configuration differing from defaults
  - PARAMETER+="add values": append values to a parameter already defined
    as intrinsic default or in a *previously* read file (Issue #457)
  - TLP_WARN_LEVEL: warn about invalid settings, configurable for background
    tasks and command line
  - Rename parameters (backwards compatible to legacy config files):
    SATA_LINKPWR_BLACKLIST      -> SATA_LINKPWR_DENYLIST
    RUNTIME_PM_BLACKLIST        -> RUNTIME_PM_DENYLIST
    RUNTIME_PM_DRIVER_BLACKLIST -> RUNTIME_PM_DRIVER_DENYLIST
    USB_BLACKLIST               -> USB_DENYLIST
    USB_BLACKLIST_BTUSB         -> USB_EXCLUDE_BTUSB
    USB_BLACKLIST_PHONE         -> USB_EXCLUDE_PHONE
    USB_BLACKLIST_PRINTER       -> USB_EXCLUDE_PRINTER
    USB_BLACKLIST_WWAN          -> USB_EXCLUDE_WWAN
    USB_WHITELIST               -> USB_ALLOWLIST
    Disks:
  - AHCI_RUNTIME_PM_ON_AC/BAT:
  - Works only on disks defined in DISK_DEVICES
  - Works on NVMe (new), SATA/ATA and plugged in USB (new) disks
  - Works on SATA ports
  - No longer experimental i.e. now enabled by default; the previously
    existing risk of system freezes (and data loss) with the multiqueue
    scheduler is now eliminated:
  - Kernel >= 4.19 itself locks unsafe disk runtime pm
  - TLP generally locks it for kernel < 4.19
  - DISK_APM_CLASS_DENYLIST: exclude disk classes from APM, i.e. you may
    now activate it for USB and IEEE1394 drives (Issue #523)
  - DISK_APM_LEVEL_ON_AC/BAT, DISK_SPINDOWN_TIMEOUT_ON_AC, DISK_IOSCHED:
    now also work when plugging in USB disks; provided disk is contained in
    DISK_DEVICES and 'usb' is removed from DISK_APM_CLASS_DENYLIST
  - tlp-stat -d
  - Explain why AHCI_RUNTIME_PM is locked for a disk
  - Show disks attached to SATA links/ports
  - Show a disk's host (for SATA_LINKPWR_DENYLIST)
  - Show ALPM state in the sysfs directory of the AHCI host
  - Show IDs for all disks configured in DISK_DEVICES
  - Distinguish SATA from ATA(IDE) disks
  - Show NVMe disk temperature
    General:
  - power-profiles-daemon: issue error messages about conflicting service
  - tlp-stat -s: determine OS release without the lsb_release utility
    Graphics:
  - Add support for amdgpu (Issue #498)
  - Improve powerdown of unused GPUs with drivers amdgpu, nouveau,
    nvidia and without driver (Issues #488, #495, #498)
  - tlp-stat -g:
  - List all GPUs with at least the driver info
  - Show hybrid graphics switch state (switcheroo)
  - Intel GPU:
  - Show hardware min/max frequency instead of
    list of available frequencies (kernel change)
  - Show more informative RC6, FBC and PSR status where available
    (Issue #203)
    Operation Mode AC/BAT:
  - Speed up system shutdown/suspend by not applying AC settings anymore
  - TLP_PS_IGNORE: add USB; allow to ignore multiple power supply classes
  - tlp-stat -s: speed up power source detection
  - tlp-stat --psup/udev: check if udev rules for power source changes and
    connecting USB devices are active
    PCI(e) devices:
  - RUNTIME_PM_ENABLE/DISABLE: permanently enable/disable runtime PM for
    PCI(e) devices based on address (independent of the power source)
  - RUNTIME_PM_DENYLIST: remove amdgpu, nvidia, pcieport from defaults
  - tlp-stat -e -v: show device runtime_status
    Platform:
  - PLATFORM_PROFILE_ON_AC/BAT: select platform profile to control system
    operating characteristics around power/performance levels, thermal
    and fan speed
  - tlp-stat -p: show state of ThinkPad lapmode
    Processor:
  - CPU_HWP_DYN_BOOST_ON_AC/BAT: Intel CPU HWP dynamic boost (Issue #468)
  - Remove backwards compatibility of CPU_ENERGY_PERF_POLICY_ON_AC/BAT with
    ENERGY_PERF_POLICY_ON_AC/BAT to prevent performance issues caused by the
    value 'power' in legacy configurations
  - PHC_CONTROLS removed (obsolete)
  - tlp-stat -p:
  - cpu1..cpuN omitted for clarity, use -v to show all
  - Sort more than 10 CPU cores in proper numerical order
  - Show intel_pstate operation mode ("status")
  - Omit "EPB: unsupported" for AMD or non-intel_pstate CPUs
    USB:
  - USB_EXCLUDE_AUDIO: exclude audio devices from autosuspend (Issue #556)
  - tlp-stat -u -v: show device runtime_status
* Mon Nov  8 2021 Fabian Vogt <fvogt@suse.com>
- Don't recommend bbswitch, there's no relation to tlp (boo#1190631)
* Wed Oct  6 2021 Fabian Vogt <fvogt@suse.com>
- tlp-sleep.service does not exist anymore
- Make %%files section a bit more precise
* Thu Jun 17 2021 Stanislav Brabec <sbrabec@suse.com>
- Recommend bbswitch for ThinkPad battery charge control instead of
  acpi-call or tp-smapi not present in the distribution.
* Mon Jan  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Use the same value for TLP_ULIB in the %%build phase and the
  %%install phase (boo#1180495):
  + BuildRequire pkgconfig(udev)
  + Use pkg-config --variable udev_dir udev for the value of
    TLP_ULIB.
* Fri Oct  9 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Properly install udev files to /usr/lib/udev, NOT /usr/libexec
  (boo#1177313).
* Fri Feb  7 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.3.1
  * default CPU_ENERGY_PERF_POLICY_ON_BAT=power too aggressive (issue#460)
* Tue Feb  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.3.0
  * New configuration scheme
  - /etc/default/tlp is replaced by /etc/tlp.conf
  - Settings are read in the following order:
  - 1. Intrinsic defaults
  - 2. /etc/tlp.d/*.conf - Drop-in customization snippets
  - 3. /etc/tlp.conf - User configuration
  - In case of identical parameters, the last occurence has precedence
  - Parse config files instead of sourcing --> no more shell expansion
  * Battery Features, tlp-stat -b
  - Charge thresholds: better checks for command line and configuration; clearer error messages
  - tlp discharge: error message "check your hardware" when battery wasn't completely discharged (Issue #438)
  - Distinguish between "no kernel support" for natacpi (< 4.17) and "laptop not supported" (>= 4.17)
  - Supplement battery status "Unknown" with "threshold may prevent charging" when thresholds are available only
  * General
  - systemd: replace tlp-sleep.service with /lib/systemd/system-sleep/tlp
  * Operation Mode AC/BAT
  - TLP_PS_IGNORE: power supply class to ignore when determining operation mode; workaround for laptops reporting incorrect AC or battery status (Issue #446)
  * PCI(e) devices
  - PCIE_ASPM_ON_AC/BAT: add method 'powersupersave' (Issue #425)
  * Processor
  - CPU_ENERGY_PERF_POLICY_ON_AC/BAT: backward compatible merge of settings for Intel energy vs. performance policies EPB (ENERGY_PERF_POLICY_ON_AC/BAT) and HWP.EPP (CPU_HWP_ON_AC/BAT); when HWP.EPP is available, EPB is not set; validate parameters; eliminate external tool x86_energy_perf_policy for kernel >= 5.2
  * tlp-stat
  - Configuration: show file where the parameter comes from
  - System Info:
    Show SELinux status
    Show RDW as 'disabled' when TLP is disabled as a whole
    Indicate persistent mode
  - Intel CPU: don't show EPB values when HWP.EPP is active (see above)
  - PCIe ASPM: show available policies
  - Undervolting: remove "PHC kernel not available" message
  * Battery Features
  - Issue #415: ThinkPad X240 discharge BAT1 malfunction when BAT0 is not installed
  * Disks
  - Fix NVMe detection on Linux 4.15
  * tlp-stat
  - Issue #430: ignore HID device batteries
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Sun May 19 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.2.2:
  * Battery Features, tlp-stat -b:
  - Show data for batteries named other than BAT0/BAT1
    (non-ThinkPads).
  - ThinkPad X1C6 discharge malfunction (gh#linrunner/TLP#395).
  - Separate checks for charge thresholds and recalibration.
  - Intelligible recommendation for tp-smapi on
    ThinkPad X220/T420 et al.
  - Explain "Battery Features: Charge Thresholds and Recalibrate".
  * Discs:
  - Fix type determination.
  * Operation Mode AC/BAT:
  - MacBookPro 5.3: Workaround for false AC offline status.
  * Processor, tlp-stat -p:
  - Fix read of /sys/devices/system/cpu/cpufreq/boost.
  - x86_energy_perf_policy: Detect unsupported CPUs in newer
    versions.
  * Radio Devices:
  - Make RESTORE_DEVICE_STATE_ON_STARTUP=1 persistent again
    (gh#linrunner/TLP#404).
* Mon Mar 18 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.2.1:
  * Fix unknown command "chargeonce" (gh#linrunner/TLP#391).
- Change from %%systemd_requires to %%systemd_ordering
* Wed Mar 13 2019 sor.alexei@meowr.ru
- Update to version 1.2:
  * Disc drives:
  - Support for NVMe devices.
  - Support for removable drives e.g. USB / IEE1394 devices.
  - Improve support for multi queue I/O schedulers (blk-mq).
  * General:
  - tlp bat/ac: Keep manual power settings until tlp start
    (gh#linrunner/TLP#349).
  - Remove all pm-utils scripts (gh#linrunner/TLP#363).
  - tlp/tlp-stat: Temporarily overwrite configuration for one
    programme invocation only: -- PARAM=value ...
  - Document intrinsic defaults in config file
    (gh#linrunner/TLP#353).
  - Code verified with ShellCheck.
  * Graphics:
  - INTEL_GPU_MIN_FREQ_ON_AC/BAT, INTEL_GPU_MAX_FREQ_ON_AC/BAT,
    INTEL_GPU_BOOST_FREQ_ON_AC/BAT: Intel GPU frequency limits.
  * Radio Devices:
  - tlp-rdw: New command to disable RDW actions temporarily
    (until reboot).
  - Support ThinkPad Pro Dock CS18 (17ef:306f).
  - USB_BLACKLIST_WWAN: Disable by default.
  - Retire compatibility with Network Manager 0.9.8.
  * PCI(e) devices:
  - RUNTIME_PM_BLACKLIST: Add mei_me, pcieport.
  * ThinkPad Battery:
  - New native kernel API for battery features "natacpi",
    requires kernel 4.17; enabled by default
    (gh#linrunner/TLP#321).
  - NATACPI_ENABLE, TPACPI_ENABLE, TPSMAPI_ENABLE: Make all
    battery feature drivers switchable.
  - tlp discharge/recalibrate: Exclude multiple simultaneous
    invocations.
  - Support ThinkPad 25, *80 (Coffee Lake) and all newer models.
  * tlp-stat:
  - Check systemd-rfkill.socket masked status.
  - Drives: Show all configured devices (consider default).
  - Intel GPU: Show frequency limits and available frequencies.
  - Rename "Suggestions" section to "Recommendations".
  - Remove invocation via "tlp stat".
  * USB:
  - Exclude scanners managed by libsane from autosuspend.
  - Remove long deprecated level/autosuspend attributes.
  * Bugfixes
  - Do not try to start NetworkManager (systemd)
    (gh#linrunner/TLP#193).
  - get_disk_dev logic is not compatible with NVMe devices
    (gh#linrunner/TLP#319).
  - AC mode not detected with USB charger (gh#linrunner/TLP#320).
  - Process "/usr/bin/tlp auto" failed with exit code 4
    (gh#linrunner/TLP#331).
  - zsh parse error in tlp diskid (gh#linrunner/TLP#332).
  - Circumvent broken AC/charger detection (gh#linrunner/TLP#343,
    gh#linrunner/TLP#362, gh#linrunner/TLP#375).
  - Keep ASPM default to enable deeper C-states on AC
    (gh#linrunner/TLP#344).
  - Fix writing sequence for start/stop charge thresholds
    (gh#linrunner/TLP#356).
  - Recognise Think*p*ad P50 (gh#linrunner/TLP#368).
  - tlp-stat: filter HWP lines from x86_energy_perf_policy output
* Wed Jan 24 2018 sor.alexei@meowr.ru
- Update to version 1.1:
  * Disc drives:
  - SATA_LINKPWR_ON_AC/BAT: Try multiple values to support the
    new recommended ALPM policy "med_power_with_dipm" in
    Linux 4.15.
  * Processor:
  - ENERGY_PERF_POLICY_ON_AC/BAT: Support changed values:
    performance, balance-performance, default, balance-power,
    power (gh#linrunner/TLP#297).
  * ThinkPad Battery:
  - Support ThinkPad 13 1st & 2nd Gen, E130;
    new tpacpi-bat version.
  - tlp-stat --psup: Show ASLbase for tpacpi-bat (in device/path).
  - tlp discharge: Show state of the battery and force_discharge.
  * USB:
  - USB_BLACKLIST_PRINTER: Exclude printers from autosuspend.
  * Bugfixes:
  - Intercept the link_power_management_policy write error
    (gh#linrunner/TLP#271).
  - Fix AC power detection for MacBook Pro 2017
    (gh#linrunner/TLP#283).
  - Move runtime data from /var/run/tlp to /run/tlp
    (gh#linrunner/TLP#298).
  - Fix DEVICES_TO_DISABLE_ON_BAT_NOT_IN_USE="bluetooth" not
    working as expected (gh#linrunner/TLP#301).
  - Do not detect wireless input devices batteries as power
    supply (gh#linrunner/TLP#313).
- Remove tlp-1.0-run-mount.patch: fixed upstream.
* Sun Nov 26 2017 sor.alexei@meowr.ru
- Add tlp-1.0-run-mount.patch: Move runtime data from /var/run/tlp
  to /run/tlp (boo#1058983)
* Fri May 26 2017 sor.alexei@meowr.ru
- Update to version 1.0:
  * General:
  - TLP_PERSISTENT_DEFAULT: Use TLP_DEFAULT_MODE regardless of
    the actual power source.
  * Device Bays:
  - BAY_POWEROFF_ON_AC: Power off optical drive not only on bat
    (gh#linrunner/TLP#243)
  * Graphics:
  - RUNTIME_PM_DRIVER_BLACKLIST: When unconfigured default to
    "amdgpu nouveau nvidia radeon"; driver default control=auto
    allows PRIME/Bumblebee to turn the dGPU off and prevents
    accidential power-on during boot as well.
  - Exclude Nvidia dGPU from runtime power management even when
    no driver is associated (improve compatibility with
    Bumblebee).
  * PCI(e) devices
  - RUNTIME_PM_ALL removed (default to RUNTIME_PM_ALL=1
    internally).
  * Processor:
  - CPU_HWP_ON_AC/BAT: HWP energy performance hints; needs
    Linux 4.10 and Intel Skylake CPU or newer, intel_pstate only.
  * ThinkPad Battery:
  - RESTORE_THRESHOLDS_ON_BAT: Restore charge thresholds on
    battery.
  - Detect ThinkPad *70 models.
  - Detect ThinkPad 13 (1st and 2nd Gen) as unsupported
    (gh#linrunner/TLP#227).
  - Change texts "ThinkPad (extended) battery functions" to
    "ThinkPad battery features".
  - tlp-stat:
    + Show "Charge total %%" when more than one battery is
    present.
    + Show battery temperature (tp-smapi only).
    + Show "unsupported" instead of "not installed" for tp-smapi
    incapable hardware.
  * USB:
  - USB_BLACKLIST_BTUSB: exclude bluetooth devices from
    autosuspend (gh#linrunner/TLP#239).
  - USB_BLACKLIST_PHONE: exclude phone devices from
    autosuspend (gh#linrunner/TLP#188).
  * tlp-stat:
  - -g|--graphics: Show graphics card data only.
  - i915: Explain enable_psr modes.
  - --psup: show power supply diagnostic.
  - SMART attribute G-Sense_Error_Rate.
  - -v: additional battery voltages.
  - Workqueue power efficient status.
  - Show Intel graphics parameters for Ubuntu's i915_bpo module.
  * Bugfixes:
  - init start: Apply powersave regardless of previous state
    (gh#linrunner/TLP#237).
  - tlp-stat: Intercept non-existing or invalid charge values
    (gh#linrunner/TLP#256).
* Thu Aug 18 2016 sor.alexei@meowr.ru
- Update to version 0.9:
  * General:
  - Block concurrent invocation of TLP.
  * Disc drives:
  - AHCI runtime power management for host controllers and
    attached disc drives.
  - SATA_LINKPWR_BLACKLIST: Exclude SATA host devices from power
    management.
  * Radio Devices:
  - Finally remove deprecated DEVICES_TO_ENABLE_ON_RADIOSW code
    (works with Ubuntu 12.04/Linux 3.2 only).
  - Change WIFI_PWR_ON_AC/BAT default config values to off/on for
    better usability (1/5 is still supported for backwards
    compatibility).
  * Radio Device Wizard (tlp-rdw):
  - Add another ThinkPad OneLink Pro Dock USB LAN (17ef:304).
  * (ThinkPad) Battery:
  - tlp-stat:
    + Distinguish incompatible hardware from load errors
    (gh#linrunner/TLP#160).
    + Display battery charge and capacity values in %%.
    + More selective suggestions for tp-smapi/acpi-call kernel
    modules.
  * tlp-stat:
  - Intel graphics: include i915 parameters enable_dc, enable_psr,
    modeset.
  - --pev: monitor power supply udev events
    (gh#linrunner/TLP#172).
  - Processor:
    + Display available scaling governors.
    + intel_pstate: display turbo_pct, num_pstates.
  - Storage Devices:
  - Recognise blk-mq I/O scheduler.
  - SMART attributes Power_Cycle_Count, Unused_Rsvd_Blk_Cnt_Tot,
    NAND_Writes_1GiB.
  - Suggestions: Add *60 models for tp-smapi/acpi-call.
  - System Info: Display boot mode UEFI / BIOS.
  - TLP Status:
    + Display time and mode of tlp's last invocation.
    + Issue warning when systemd-rfkill[@].service is not masked.
  - Wireless: Display type in interface list.
  * Bugfixes
  - Handle kernel with built-in acpi_call module properly
    (gh#linrunner/TLP#163).
  - Battery discharge does not terminate on ThinkPad E-series
    (gh#linrunner/TLP#170).
  - TLP does not notice power source change (gh#linrunner/TLP#172).
  - Do not touch wifi on shutdown when unconfigured
    (gh#linrunner/TLP#175).
  - Optimise rdw locking heuristics (gh#linrunner/TLP#176).
  - tlp-stat: Fix ata error count (filter "DevExch" caused by
    bay inserts).
  - tp-smapi: Do not load on unsupported ThinkPads.
  - Fix bash completion.
- Remove tlp-0.8-correct-udev-rules-path.patch: fixed upstream.
* Mon Jan  4 2016 sor.alexei@meowr.ru
- Add tlp-0.8-correct-udev-rules-path.patch: set correct udev
  rules path (boo#960498).
* Thu Aug  6 2015 sor.alexei@meowr.ru
- Update to 0.8:
  * General:
  - TLP_DEFAULT_MODE: change default operation mode to AC when
    no power supply can be detected (concerns some desktop and
    embedded hardware only).
  * Radio Devices:
  - Resume: restore bluetooth state.
  * Radio Device Wizard (tlp-rdw):
  - Support ThinkPad OneLink Dock Basic/Pro for dock/undock
    events.
  - Detect systemd "predictable network interface names" for
    WWAN.
  * ThinkPad Battery:
  - tpacpi-bat: new upstream version 2.2: get ASL path from
    /sys/class/power_supply/*/device/path; avoids unnecessary
    "AE_NOT_FOUND" kernel messages.
  - tlp-stat:
  - Show "No batteries detected."
  - Explain battery status "Unknown" as "threshold effective".
  - Show battery cell group voltages (verbose mode, tp-smapi
    only).
  - Show acpi-call suggestion for ThinkPad *40, *50, X1
    models.
  * USB:
  - Remove USB_DRIVER_BLACKLIST.
  * tlp-stat:
  - Show warnings for ata errors by default.
  * Bugfixes:
  - tlp-stat: detect kernel config with PM_RUNTIME=N.
  - tlp recalibrate: fix exitcode check.
  - USB autosuspend: write power/control if actually changing
    only.
  - Ignore missing files in /proc/sys/fs/xfs.
  - Fix udev event processing for AC/BAT sw.
* Sat Jan 31 2015 sor.alexei@meowr.ru
- Update to 0.7:
  * Processor:
  - Limit max/min P-state to control power dissipation of the
    CPU (intel_pstate only)
  - Set performance versus energy savings policy
    (x86_energy_perf_policy)
  * USB:
  - USB_DRIVER_BLACKLIST: exclude devices assigned to the listed
    drivers from USB autosuspend; default: usbhid
  - USB_BLACKLIST_WWAN: match internal driver list instead of USB
    vendor ids
  - USB_WHITELIST: include devices into USB autosuspend even if
    already excluded by the driver or WWAN blacklists
  * Radio devices:
  - DEVICES_TO_ENABLE_ON_AC/DISABLE_ON_BAT /
    DISABLE_ON_BAT_NOT_IN_USE: enable/disable radio devices upon
    change of power source (excluding connected devices)
  * ThinkPad Battery:
  - Issue #105: provide proper return codes for all battery
    functions
  - Issue #106: setcharge allowed on battery power
  - Do not activate new thresholds with force_discharge anymore
    (tp-smapi)
  - tpacpi-bat: support for ThinkPad E325 charge thresholds
  * Misc:
  - RUNTIME_PM_DRIVER_BLACKLIST: exclude PCI(e) devices assigned
    to drivers;
    default: radeon, nouveau (solves issue #94)
  - Support Dell Latitude docks
  - Support for NM 0.9.10
  - Issue #109: tlp-stat: report "unknown" power source when no
    AC detected
  - Issue #98: do not change autosuspend_delay_ms, keep kernel
    default settings
  - Exclude pseudo usb disks
  * tlp-stat:
  - New options -d|--disk, -e|--pcie, -p|--processor,
  - s|--system, -u|--usb
  - Show driver and connection state for all enabled radio
    devices
  - Show driver name in Runtime PM PCI(e) device list
  - Show type and state of docks and device bays
  - Show type of init system
  - Check if TLP's systemd services are enabled
  * udev:
  - Run change of power source in a detached subshell to avoid
    blocking udev
  - Fix dock/undock event processing for ThinkPad Adv Mini Dock
    and Ultrabase
  - Make USB device event processing more robust
    + Run in a detached subshell to avoid blocking udev
    + Wait 2s for subdevices to populate for proper
    black/whitelist detection
* Thu Nov 20 2014 sor.alexei@meowr.ru
- Adjust dependencies according to
  http://linrunner.de/en/tlp/docs/tlp-developer-documentation.html
* Wed Oct  8 2014 sor.alexei@meowr.ru
- Initial build.
